/*
 * nghttp3
 *
 * Copyright (c) 2019 nghttp3 contributors
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#include "nghttp3_err.h"

const char *nghttp3_strerror(int liberr) {
  switch (liberr) {
  case NGHTTP3_ERR_INVALID_ARGUMENT:
    return "ERR_INVALID_ARGUMENT";
  case NGHTTP3_ERR_NOBUF:
    return "ERR_NOBUF";
  case NGHTTP3_ERR_INVALID_STATE:
    return "ERR_INVALID_STATE";
  case NGHTTP3_ERR_WOULDBLOCK:
    return "ERR_WOULDBLOCK";
  case NGHTTP3_ERR_STREAM_IN_USE:
    return "ERR_STREAM_IN_USE";
  case NGHTTP3_ERR_PUSH_ID_BLOCKED:
    return "ERR_PUSH_ID_BLOCKED";
  case NGHTTP3_ERR_MALFORMED_HTTP_HEADER:
    return "ERR_MALFORMED_HTTP_HEADER";
  case NGHTTP3_ERR_REMOVE_HTTP_HEADER:
    return "ERR_REMOVE_HTTP_HEADER";
  case NGHTTP3_ERR_MALFORMED_HTTP_MESSAGING:
    return "ERR_MALFORMED_HTTP_MESSAGING";
  case NGHTTP3_ERR_TOO_LATE:
    return "ERR_TOO_LATE";
  case NGHTTP3_ERR_QPACK_FATAL:
    return "ERR_QPACK_FATAL";
  case NGHTTP3_ERR_QPACK_HEADER_TOO_LARGE:
    return "ERR_QPACK_HEADER_TOO_LARGE";
  case NGHTTP3_ERR_IGNORE_STREAM:
    return "ERR_IGNORE_STREAM";
  case NGHTTP3_ERR_HTTP_QPACK_DECOMPRESSION_FAILED:
    return "ERR_HTTP_QPACK_DECOMPRESSION_FAILED";
  case NGHTTP3_ERR_HTTP_QPACK_ENCODER_STREAM_ERROR:
    return "ERR_HTTP_QPACK_ENCODER_STREAM_ERROR";
  case NGHTTP3_ERR_HTTP_QPACK_DECODER_STREAM_ERROR:
    return "ERR_HTTP_QPACK_DECODER_STREAM_ERROR";
  case NGHTTP3_ERR_HTTP_UNEXPECTED_FRAME:
    return "ERR_HTTP_UNEXPECTED_FRAME";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_DATA:
    return "ERR_HTTP_MALFORMED_FRAME_DATA";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_HEADERS:
    return "ERR_HTTP_MALFORMED_FRAME_HEADERS";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_PRIORITY:
    return "ERR_HTTP_MALFORMED_FRAME_PRIORITY";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_CANCEL_PUSH:
    return "ERR_HTTP_MALFORMED_FRAME_CANCEL_PUSH";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_SETTINGS:
    return "ERR_HTTP_MALFORMED_FRAME_SETTINGS";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_PUSH_PROMISE:
    return "ERR_HTTP_MALFORMED_FRAME_PUSH_PROMISE";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_GOAWAY:
    return "ERR_HTTP_MALFORMED_FRAME_GOAWAY";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_MAX_PUSH_ID:
    return "ERR_HTTP_MALFORMED_FRAME_MAX_PUSH_ID";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_DUPLICATE_PUSH:
    return "ERR_HTTP_MALFORMED_FRAME_DUPLICATE_PUSH";
    /* Generated by genstrerror.py */
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x06:
    return "ERR_HTTP_MALFORMED_FRAME_0X06";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x08:
    return "ERR_HTTP_MALFORMED_FRAME_0X08";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x09:
    return "ERR_HTTP_MALFORMED_FRAME_0X09";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x0a:
    return "ERR_HTTP_MALFORMED_FRAME_0X0A";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x0b:
    return "ERR_HTTP_MALFORMED_FRAME_0X0B";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x0c:
    return "ERR_HTTP_MALFORMED_FRAME_0X0C";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x0f:
    return "ERR_HTTP_MALFORMED_FRAME_0X0F";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x10:
    return "ERR_HTTP_MALFORMED_FRAME_0X10";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x11:
    return "ERR_HTTP_MALFORMED_FRAME_0X11";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x12:
    return "ERR_HTTP_MALFORMED_FRAME_0X12";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x13:
    return "ERR_HTTP_MALFORMED_FRAME_0X13";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x14:
    return "ERR_HTTP_MALFORMED_FRAME_0X14";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x15:
    return "ERR_HTTP_MALFORMED_FRAME_0X15";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x16:
    return "ERR_HTTP_MALFORMED_FRAME_0X16";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x17:
    return "ERR_HTTP_MALFORMED_FRAME_0X17";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x18:
    return "ERR_HTTP_MALFORMED_FRAME_0X18";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x19:
    return "ERR_HTTP_MALFORMED_FRAME_0X19";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x1a:
    return "ERR_HTTP_MALFORMED_FRAME_0X1A";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x1b:
    return "ERR_HTTP_MALFORMED_FRAME_0X1B";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x1c:
    return "ERR_HTTP_MALFORMED_FRAME_0X1C";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x1d:
    return "ERR_HTTP_MALFORMED_FRAME_0X1D";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x1e:
    return "ERR_HTTP_MALFORMED_FRAME_0X1E";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x1f:
    return "ERR_HTTP_MALFORMED_FRAME_0X1F";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x20:
    return "ERR_HTTP_MALFORMED_FRAME_0X20";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x21:
    return "ERR_HTTP_MALFORMED_FRAME_0X21";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x22:
    return "ERR_HTTP_MALFORMED_FRAME_0X22";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x23:
    return "ERR_HTTP_MALFORMED_FRAME_0X23";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x24:
    return "ERR_HTTP_MALFORMED_FRAME_0X24";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x25:
    return "ERR_HTTP_MALFORMED_FRAME_0X25";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x26:
    return "ERR_HTTP_MALFORMED_FRAME_0X26";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x27:
    return "ERR_HTTP_MALFORMED_FRAME_0X27";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x28:
    return "ERR_HTTP_MALFORMED_FRAME_0X28";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x29:
    return "ERR_HTTP_MALFORMED_FRAME_0X29";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x2a:
    return "ERR_HTTP_MALFORMED_FRAME_0X2A";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x2b:
    return "ERR_HTTP_MALFORMED_FRAME_0X2B";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x2c:
    return "ERR_HTTP_MALFORMED_FRAME_0X2C";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x2d:
    return "ERR_HTTP_MALFORMED_FRAME_0X2D";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x2e:
    return "ERR_HTTP_MALFORMED_FRAME_0X2E";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x2f:
    return "ERR_HTTP_MALFORMED_FRAME_0X2F";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x30:
    return "ERR_HTTP_MALFORMED_FRAME_0X30";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x31:
    return "ERR_HTTP_MALFORMED_FRAME_0X31";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x32:
    return "ERR_HTTP_MALFORMED_FRAME_0X32";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x33:
    return "ERR_HTTP_MALFORMED_FRAME_0X33";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x34:
    return "ERR_HTTP_MALFORMED_FRAME_0X34";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x35:
    return "ERR_HTTP_MALFORMED_FRAME_0X35";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x36:
    return "ERR_HTTP_MALFORMED_FRAME_0X36";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x37:
    return "ERR_HTTP_MALFORMED_FRAME_0X37";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x38:
    return "ERR_HTTP_MALFORMED_FRAME_0X38";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x39:
    return "ERR_HTTP_MALFORMED_FRAME_0X39";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x3a:
    return "ERR_HTTP_MALFORMED_FRAME_0X3A";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x3b:
    return "ERR_HTTP_MALFORMED_FRAME_0X3B";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x3c:
    return "ERR_HTTP_MALFORMED_FRAME_0X3C";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x3d:
    return "ERR_HTTP_MALFORMED_FRAME_0X3D";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x3e:
    return "ERR_HTTP_MALFORMED_FRAME_0X3E";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x3f:
    return "ERR_HTTP_MALFORMED_FRAME_0X3F";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x40:
    return "ERR_HTTP_MALFORMED_FRAME_0X40";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x41:
    return "ERR_HTTP_MALFORMED_FRAME_0X41";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x42:
    return "ERR_HTTP_MALFORMED_FRAME_0X42";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x43:
    return "ERR_HTTP_MALFORMED_FRAME_0X43";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x44:
    return "ERR_HTTP_MALFORMED_FRAME_0X44";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x45:
    return "ERR_HTTP_MALFORMED_FRAME_0X45";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x46:
    return "ERR_HTTP_MALFORMED_FRAME_0X46";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x47:
    return "ERR_HTTP_MALFORMED_FRAME_0X47";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x48:
    return "ERR_HTTP_MALFORMED_FRAME_0X48";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x49:
    return "ERR_HTTP_MALFORMED_FRAME_0X49";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x4a:
    return "ERR_HTTP_MALFORMED_FRAME_0X4A";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x4b:
    return "ERR_HTTP_MALFORMED_FRAME_0X4B";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x4c:
    return "ERR_HTTP_MALFORMED_FRAME_0X4C";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x4d:
    return "ERR_HTTP_MALFORMED_FRAME_0X4D";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x4e:
    return "ERR_HTTP_MALFORMED_FRAME_0X4E";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x4f:
    return "ERR_HTTP_MALFORMED_FRAME_0X4F";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x50:
    return "ERR_HTTP_MALFORMED_FRAME_0X50";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x51:
    return "ERR_HTTP_MALFORMED_FRAME_0X51";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x52:
    return "ERR_HTTP_MALFORMED_FRAME_0X52";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x53:
    return "ERR_HTTP_MALFORMED_FRAME_0X53";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x54:
    return "ERR_HTTP_MALFORMED_FRAME_0X54";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x55:
    return "ERR_HTTP_MALFORMED_FRAME_0X55";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x56:
    return "ERR_HTTP_MALFORMED_FRAME_0X56";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x57:
    return "ERR_HTTP_MALFORMED_FRAME_0X57";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x58:
    return "ERR_HTTP_MALFORMED_FRAME_0X58";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x59:
    return "ERR_HTTP_MALFORMED_FRAME_0X59";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x5a:
    return "ERR_HTTP_MALFORMED_FRAME_0X5A";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x5b:
    return "ERR_HTTP_MALFORMED_FRAME_0X5B";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x5c:
    return "ERR_HTTP_MALFORMED_FRAME_0X5C";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x5d:
    return "ERR_HTTP_MALFORMED_FRAME_0X5D";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x5e:
    return "ERR_HTTP_MALFORMED_FRAME_0X5E";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x5f:
    return "ERR_HTTP_MALFORMED_FRAME_0X5F";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x60:
    return "ERR_HTTP_MALFORMED_FRAME_0X60";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x61:
    return "ERR_HTTP_MALFORMED_FRAME_0X61";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x62:
    return "ERR_HTTP_MALFORMED_FRAME_0X62";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x63:
    return "ERR_HTTP_MALFORMED_FRAME_0X63";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x64:
    return "ERR_HTTP_MALFORMED_FRAME_0X64";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x65:
    return "ERR_HTTP_MALFORMED_FRAME_0X65";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x66:
    return "ERR_HTTP_MALFORMED_FRAME_0X66";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x67:
    return "ERR_HTTP_MALFORMED_FRAME_0X67";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x68:
    return "ERR_HTTP_MALFORMED_FRAME_0X68";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x69:
    return "ERR_HTTP_MALFORMED_FRAME_0X69";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x6a:
    return "ERR_HTTP_MALFORMED_FRAME_0X6A";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x6b:
    return "ERR_HTTP_MALFORMED_FRAME_0X6B";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x6c:
    return "ERR_HTTP_MALFORMED_FRAME_0X6C";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x6d:
    return "ERR_HTTP_MALFORMED_FRAME_0X6D";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x6e:
    return "ERR_HTTP_MALFORMED_FRAME_0X6E";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x6f:
    return "ERR_HTTP_MALFORMED_FRAME_0X6F";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x70:
    return "ERR_HTTP_MALFORMED_FRAME_0X70";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x71:
    return "ERR_HTTP_MALFORMED_FRAME_0X71";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x72:
    return "ERR_HTTP_MALFORMED_FRAME_0X72";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x73:
    return "ERR_HTTP_MALFORMED_FRAME_0X73";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x74:
    return "ERR_HTTP_MALFORMED_FRAME_0X74";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x75:
    return "ERR_HTTP_MALFORMED_FRAME_0X75";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x76:
    return "ERR_HTTP_MALFORMED_FRAME_0X76";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x77:
    return "ERR_HTTP_MALFORMED_FRAME_0X77";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x78:
    return "ERR_HTTP_MALFORMED_FRAME_0X78";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x79:
    return "ERR_HTTP_MALFORMED_FRAME_0X79";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x7a:
    return "ERR_HTTP_MALFORMED_FRAME_0X7A";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x7b:
    return "ERR_HTTP_MALFORMED_FRAME_0X7B";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x7c:
    return "ERR_HTTP_MALFORMED_FRAME_0X7C";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x7d:
    return "ERR_HTTP_MALFORMED_FRAME_0X7D";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x7e:
    return "ERR_HTTP_MALFORMED_FRAME_0X7E";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x7f:
    return "ERR_HTTP_MALFORMED_FRAME_0X7F";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x80:
    return "ERR_HTTP_MALFORMED_FRAME_0X80";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x81:
    return "ERR_HTTP_MALFORMED_FRAME_0X81";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x82:
    return "ERR_HTTP_MALFORMED_FRAME_0X82";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x83:
    return "ERR_HTTP_MALFORMED_FRAME_0X83";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x84:
    return "ERR_HTTP_MALFORMED_FRAME_0X84";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x85:
    return "ERR_HTTP_MALFORMED_FRAME_0X85";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x86:
    return "ERR_HTTP_MALFORMED_FRAME_0X86";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x87:
    return "ERR_HTTP_MALFORMED_FRAME_0X87";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x88:
    return "ERR_HTTP_MALFORMED_FRAME_0X88";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x89:
    return "ERR_HTTP_MALFORMED_FRAME_0X89";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x8a:
    return "ERR_HTTP_MALFORMED_FRAME_0X8A";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x8b:
    return "ERR_HTTP_MALFORMED_FRAME_0X8B";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x8c:
    return "ERR_HTTP_MALFORMED_FRAME_0X8C";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x8d:
    return "ERR_HTTP_MALFORMED_FRAME_0X8D";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x8e:
    return "ERR_HTTP_MALFORMED_FRAME_0X8E";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x8f:
    return "ERR_HTTP_MALFORMED_FRAME_0X8F";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x90:
    return "ERR_HTTP_MALFORMED_FRAME_0X90";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x91:
    return "ERR_HTTP_MALFORMED_FRAME_0X91";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x92:
    return "ERR_HTTP_MALFORMED_FRAME_0X92";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x93:
    return "ERR_HTTP_MALFORMED_FRAME_0X93";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x94:
    return "ERR_HTTP_MALFORMED_FRAME_0X94";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x95:
    return "ERR_HTTP_MALFORMED_FRAME_0X95";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x96:
    return "ERR_HTTP_MALFORMED_FRAME_0X96";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x97:
    return "ERR_HTTP_MALFORMED_FRAME_0X97";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x98:
    return "ERR_HTTP_MALFORMED_FRAME_0X98";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x99:
    return "ERR_HTTP_MALFORMED_FRAME_0X99";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x9a:
    return "ERR_HTTP_MALFORMED_FRAME_0X9A";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x9b:
    return "ERR_HTTP_MALFORMED_FRAME_0X9B";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x9c:
    return "ERR_HTTP_MALFORMED_FRAME_0X9C";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x9d:
    return "ERR_HTTP_MALFORMED_FRAME_0X9D";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x9e:
    return "ERR_HTTP_MALFORMED_FRAME_0X9E";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0x9f:
    return "ERR_HTTP_MALFORMED_FRAME_0X9F";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xa0:
    return "ERR_HTTP_MALFORMED_FRAME_0XA0";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xa1:
    return "ERR_HTTP_MALFORMED_FRAME_0XA1";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xa2:
    return "ERR_HTTP_MALFORMED_FRAME_0XA2";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xa3:
    return "ERR_HTTP_MALFORMED_FRAME_0XA3";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xa4:
    return "ERR_HTTP_MALFORMED_FRAME_0XA4";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xa5:
    return "ERR_HTTP_MALFORMED_FRAME_0XA5";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xa6:
    return "ERR_HTTP_MALFORMED_FRAME_0XA6";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xa7:
    return "ERR_HTTP_MALFORMED_FRAME_0XA7";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xa8:
    return "ERR_HTTP_MALFORMED_FRAME_0XA8";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xa9:
    return "ERR_HTTP_MALFORMED_FRAME_0XA9";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xaa:
    return "ERR_HTTP_MALFORMED_FRAME_0XAA";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xab:
    return "ERR_HTTP_MALFORMED_FRAME_0XAB";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xac:
    return "ERR_HTTP_MALFORMED_FRAME_0XAC";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xad:
    return "ERR_HTTP_MALFORMED_FRAME_0XAD";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xae:
    return "ERR_HTTP_MALFORMED_FRAME_0XAE";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xaf:
    return "ERR_HTTP_MALFORMED_FRAME_0XAF";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xb0:
    return "ERR_HTTP_MALFORMED_FRAME_0XB0";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xb1:
    return "ERR_HTTP_MALFORMED_FRAME_0XB1";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xb2:
    return "ERR_HTTP_MALFORMED_FRAME_0XB2";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xb3:
    return "ERR_HTTP_MALFORMED_FRAME_0XB3";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xb4:
    return "ERR_HTTP_MALFORMED_FRAME_0XB4";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xb5:
    return "ERR_HTTP_MALFORMED_FRAME_0XB5";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xb6:
    return "ERR_HTTP_MALFORMED_FRAME_0XB6";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xb7:
    return "ERR_HTTP_MALFORMED_FRAME_0XB7";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xb8:
    return "ERR_HTTP_MALFORMED_FRAME_0XB8";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xb9:
    return "ERR_HTTP_MALFORMED_FRAME_0XB9";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xba:
    return "ERR_HTTP_MALFORMED_FRAME_0XBA";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xbb:
    return "ERR_HTTP_MALFORMED_FRAME_0XBB";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xbc:
    return "ERR_HTTP_MALFORMED_FRAME_0XBC";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xbd:
    return "ERR_HTTP_MALFORMED_FRAME_0XBD";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xbe:
    return "ERR_HTTP_MALFORMED_FRAME_0XBE";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xbf:
    return "ERR_HTTP_MALFORMED_FRAME_0XBF";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xc0:
    return "ERR_HTTP_MALFORMED_FRAME_0XC0";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xc1:
    return "ERR_HTTP_MALFORMED_FRAME_0XC1";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xc2:
    return "ERR_HTTP_MALFORMED_FRAME_0XC2";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xc3:
    return "ERR_HTTP_MALFORMED_FRAME_0XC3";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xc4:
    return "ERR_HTTP_MALFORMED_FRAME_0XC4";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xc5:
    return "ERR_HTTP_MALFORMED_FRAME_0XC5";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xc6:
    return "ERR_HTTP_MALFORMED_FRAME_0XC6";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xc7:
    return "ERR_HTTP_MALFORMED_FRAME_0XC7";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xc8:
    return "ERR_HTTP_MALFORMED_FRAME_0XC8";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xc9:
    return "ERR_HTTP_MALFORMED_FRAME_0XC9";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xca:
    return "ERR_HTTP_MALFORMED_FRAME_0XCA";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xcb:
    return "ERR_HTTP_MALFORMED_FRAME_0XCB";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xcc:
    return "ERR_HTTP_MALFORMED_FRAME_0XCC";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xcd:
    return "ERR_HTTP_MALFORMED_FRAME_0XCD";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xce:
    return "ERR_HTTP_MALFORMED_FRAME_0XCE";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xcf:
    return "ERR_HTTP_MALFORMED_FRAME_0XCF";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xd0:
    return "ERR_HTTP_MALFORMED_FRAME_0XD0";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xd1:
    return "ERR_HTTP_MALFORMED_FRAME_0XD1";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xd2:
    return "ERR_HTTP_MALFORMED_FRAME_0XD2";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xd3:
    return "ERR_HTTP_MALFORMED_FRAME_0XD3";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xd4:
    return "ERR_HTTP_MALFORMED_FRAME_0XD4";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xd5:
    return "ERR_HTTP_MALFORMED_FRAME_0XD5";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xd6:
    return "ERR_HTTP_MALFORMED_FRAME_0XD6";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xd7:
    return "ERR_HTTP_MALFORMED_FRAME_0XD7";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xd8:
    return "ERR_HTTP_MALFORMED_FRAME_0XD8";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xd9:
    return "ERR_HTTP_MALFORMED_FRAME_0XD9";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xda:
    return "ERR_HTTP_MALFORMED_FRAME_0XDA";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xdb:
    return "ERR_HTTP_MALFORMED_FRAME_0XDB";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xdc:
    return "ERR_HTTP_MALFORMED_FRAME_0XDC";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xdd:
    return "ERR_HTTP_MALFORMED_FRAME_0XDD";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xde:
    return "ERR_HTTP_MALFORMED_FRAME_0XDE";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xdf:
    return "ERR_HTTP_MALFORMED_FRAME_0XDF";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xe0:
    return "ERR_HTTP_MALFORMED_FRAME_0XE0";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xe1:
    return "ERR_HTTP_MALFORMED_FRAME_0XE1";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xe2:
    return "ERR_HTTP_MALFORMED_FRAME_0XE2";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xe3:
    return "ERR_HTTP_MALFORMED_FRAME_0XE3";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xe4:
    return "ERR_HTTP_MALFORMED_FRAME_0XE4";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xe5:
    return "ERR_HTTP_MALFORMED_FRAME_0XE5";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xe6:
    return "ERR_HTTP_MALFORMED_FRAME_0XE6";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xe7:
    return "ERR_HTTP_MALFORMED_FRAME_0XE7";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xe8:
    return "ERR_HTTP_MALFORMED_FRAME_0XE8";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xe9:
    return "ERR_HTTP_MALFORMED_FRAME_0XE9";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xea:
    return "ERR_HTTP_MALFORMED_FRAME_0XEA";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xeb:
    return "ERR_HTTP_MALFORMED_FRAME_0XEB";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xec:
    return "ERR_HTTP_MALFORMED_FRAME_0XEC";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xed:
    return "ERR_HTTP_MALFORMED_FRAME_0XED";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xee:
    return "ERR_HTTP_MALFORMED_FRAME_0XEE";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xef:
    return "ERR_HTTP_MALFORMED_FRAME_0XEF";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xf0:
    return "ERR_HTTP_MALFORMED_FRAME_0XF0";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xf1:
    return "ERR_HTTP_MALFORMED_FRAME_0XF1";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xf2:
    return "ERR_HTTP_MALFORMED_FRAME_0XF2";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xf3:
    return "ERR_HTTP_MALFORMED_FRAME_0XF3";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xf4:
    return "ERR_HTTP_MALFORMED_FRAME_0XF4";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xf5:
    return "ERR_HTTP_MALFORMED_FRAME_0XF5";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xf6:
    return "ERR_HTTP_MALFORMED_FRAME_0XF6";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xf7:
    return "ERR_HTTP_MALFORMED_FRAME_0XF7";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xf8:
    return "ERR_HTTP_MALFORMED_FRAME_0XF8";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xf9:
    return "ERR_HTTP_MALFORMED_FRAME_0XF9";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xfa:
    return "ERR_HTTP_MALFORMED_FRAME_0XFA";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xfb:
    return "ERR_HTTP_MALFORMED_FRAME_0XFB";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xfc:
    return "ERR_HTTP_MALFORMED_FRAME_0XFC";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xfd:
    return "ERR_HTTP_MALFORMED_FRAME_0XFD";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xfe:
    return "ERR_HTTP_MALFORMED_FRAME_0XFE";
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xff:
    return "ERR_HTTP_MALFORMED_FRAME_0XFF";
  case NGHTTP3_ERR_HTTP_MISSING_SETTINGS:
    return "ERR_HTTP_MISSING_SETTINGS";
  case NGHTTP3_ERR_HTTP_WRONG_STREAM:
    return "ERR_HTTP_WRONG_STREAM";
  case NGHTTP3_ERR_HTTP_INTERNAL_ERROR:
    return "ERR_HTTP_INTERNAL_ERROR";
  case NGHTTP3_ERR_HTTP_CLOSED_CRITICAL_STREAM:
    return "ERR_CLOSED_CRITICAL_STREAM";
  case NGHTTP3_ERR_HTTP_GENERAL_PROTOCOL_ERROR:
    return "ERR_HTTP_GENERAL_PROTOCOL_ERROR";
  case NGHTTP3_ERR_HTTP_ID_ERROR:
    return "ERR_HTTP_ID_ERROR";
  case NGHTTP3_ERR_HTTP_SETTINGS_ERROR:
    return "ERR_HTTP_SETTINGS_ERROR";
  case NGHTTP3_ERR_HTTP_STREAM_CREATION_ERROR:
    return "ERR_HTTP_STREAM_CREATION_ERROR";
  case NGHTTP3_ERR_NOMEM:
    return "ERR_NOMEM";
  case NGHTTP3_ERR_CALLBACK_FAILURE:
    return "ERR_CALLBACK_FAILURE";
  default:
    return "(unknown)";
  }
}

int nghttp3_err_malformed_frame(int64_t type) {
  if (type > 0xfe) {
    return NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 0xff;
  }
  return NGHTTP3_ERR_HTTP_MALFORMED_FRAME - (int)type;
}

uint64_t nghttp3_err_infer_quic_app_error_code(int liberr) {
  switch (liberr) {
  case NGHTTP3_ERR_HTTP_QPACK_DECOMPRESSION_FAILED:
    return NGHTTP3_HTTP_QPACK_DECOMPRESSION_FAILED;
  case NGHTTP3_ERR_HTTP_QPACK_ENCODER_STREAM_ERROR:
    return NGHTTP3_HTTP_QPACK_ENCODER_STREAM_ERROR;
  case NGHTTP3_ERR_HTTP_QPACK_DECODER_STREAM_ERROR:
    return NGHTTP3_HTTP_QPACK_DECODER_STREAM_ERROR;
  case NGHTTP3_ERR_HTTP_UNEXPECTED_FRAME:
    return NGHTTP3_HTTP_UNEXPECTED_FRAME;
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_DATA:
    return NGHTTP3_HTTP_MALFORMED_FRAME + NGHTTP3_FRAME_DATA;
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_HEADERS:
    return NGHTTP3_HTTP_MALFORMED_FRAME + NGHTTP3_FRAME_HEADERS;
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_PRIORITY:
    return NGHTTP3_HTTP_MALFORMED_FRAME + NGHTTP3_FRAME_PRIORITY;
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_CANCEL_PUSH:
    return NGHTTP3_HTTP_MALFORMED_FRAME + NGHTTP3_FRAME_CANCEL_PUSH;
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_SETTINGS:
    return NGHTTP3_HTTP_MALFORMED_FRAME + NGHTTP3_FRAME_SETTINGS;
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_PUSH_PROMISE:
    return NGHTTP3_HTTP_MALFORMED_FRAME + NGHTTP3_FRAME_PUSH_PROMISE;
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_GOAWAY:
    return NGHTTP3_HTTP_MALFORMED_FRAME + NGHTTP3_FRAME_GOAWAY;
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_MAX_PUSH_ID:
    return NGHTTP3_HTTP_MALFORMED_FRAME + NGHTTP3_FRAME_MAX_PUSH_ID;
  case NGHTTP3_ERR_HTTP_MALFORMED_FRAME - NGHTTP3_FRAME_DUPLICATE_PUSH:
    return NGHTTP3_HTTP_MALFORMED_FRAME + NGHTTP3_FRAME_DUPLICATE_PUSH;
  case NGHTTP3_ERR_HTTP_MISSING_SETTINGS:
    return NGHTTP3_HTTP_MISSING_SETTINGS;
  case NGHTTP3_ERR_HTTP_WRONG_STREAM:
    return NGHTTP3_HTTP_WRONG_STREAM;
  case NGHTTP3_ERR_HTTP_INTERNAL_ERROR:
    return NGHTTP3_HTTP_INTERNAL_ERROR;
  case NGHTTP3_ERR_HTTP_CLOSED_CRITICAL_STREAM:
    return NGHTTP3_HTTP_CLOSED_CRITICAL_STREAM;
  case NGHTTP3_ERR_HTTP_GENERAL_PROTOCOL_ERROR:
    return NGHTTP3_HTTP_GENERAL_PROTOCOL_ERROR;
  case NGHTTP3_ERR_HTTP_ID_ERROR:
    return NGHTTP3_HTTP_ID_ERROR;
  case NGHTTP3_ERR_HTTP_SETTINGS_ERROR:
    return NGHTTP3_HTTP_SETTINGS_ERROR;
  case NGHTTP3_ERR_HTTP_STREAM_CREATION_ERROR:
    return NGHTTP3_HTTP_STREAM_CREATION_ERROR;
  default:
    if (NGHTTP3_ERR_HTTP_MALFORMED_FRAME >= liberr &&
        liberr > NGHTTP3_ERR_HTTP_MALFORMED_FRAME - 256) {
      return (uint64_t)(NGHTTP3_HTTP_MALFORMED_FRAME +
                        (NGHTTP3_ERR_HTTP_MALFORMED_FRAME - liberr));
    }
    return NGHTTP3_HTTP_GENERAL_PROTOCOL_ERROR;
  }
}
